import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class BoyOnAStickAndSlither(BasicComicModule):
    latestUrl = 'http://www.boasas.com/'
    imageUrl = 'http://www.boasas.com/?c=%s'
    imageSearch = re.compile(r'"(boasas/\d+\..+?)"', re.IGNORECASE)
    prevSearch = re.compile(r'<a href="(.*?)">.*?arrow_left', re.IGNORECASE)
    help = 'Index format: n (unpadded)'
